"use client"
import React, { useState } from 'react'
import EditImage from '../../components/layout/EditImage'
import useProfile from '../UseProfile';

const UserForm = ({user, onSave}) => {
    const [userName, setUserName] = useState(user?.name || '');
    const [image, setImage] = useState(user?.image || '');
    const [phoneNumber, setPhoneNumber] = useState(user?.phoneNumber || '');
    const [streetAddress, setStreetAddress] = useState(user?.streetAddress || '');
    const [city, setCity] = useState(user?.city || '');
    const [stateProvince, setStateProvince] = useState(user?.stateProvince || '');
    const [zipCode, setZipCode] = useState(user?.zipCode || '');
    const [country, setCountry] = useState(user?.country || '');
    const [admin, setAdmin] = useState(user?.admin || false);
    const {data:loginAsUser} = useProfile();


  return (
    <div className='max-w-md mx-auto mt-10'>
        <div className='flex flex-col gap-2 justify-center items-center max-w-[100px] mx-auto'>
          <EditImage link={image} setLink={setImage}/>
        </div>
        <form className='mt-5 text-sm sm:text-base flex flex-col gap-0 sm:gap-1' onSubmit={ev => onSave(ev, {name:userName, image, phoneNumber, streetAddress, city, stateProvince, zipCode, country, admin,})}>
          <div>
            <label className='text-gray-700 text-sm font-semibold'>Name</label>
            <input type='text' placeholder='Name' value={userName} onChange={ev => setUserName(ev.target.value)}/>
          </div>
          <div>
            <label className='text-gray-700 text-sm font-semibold'>Email</label>
            <input type='text' value={user.email} disabled={true} className='disabled:bg-gray-200 disabled:text-gray-400'/>
          </div>
          <div>
            <label className='text-gray-700 text-sm font-semibold'>Phone number</label>
            <input type='tel' placeholder='Phone number' value={phoneNumber} onChange={ev => setPhoneNumber(ev.target.value)}/>
          </div>
          <div>
            <label className='text-gray-700 text-sm font-semibold'>Street Address</label>
            <input type='text' placeholder='Address' value={streetAddress} onChange={ev => setStreetAddress(ev.target.value)}/>
          </div>
          <div>
            <label className='text-gray-700 text-sm font-semibold'>City</label>
            <input type='text' placeholder='City' value={city} onChange={ev => setCity(ev.target.value)}/>
          </div>
          <div className='flex flex-col sm:flex-row gap-0 sm:gap-2'>
            <div>
              <label className='text-gray-700 text-sm font-semibold'>State/Province</label>
              <input type='text' placeholder='State/Province' value={stateProvince} onChange={ev => setStateProvince(ev.target.value)}/>
            </div>
            <div>
              <label className='text-gray-700 text-sm font-semibold'>Zip/Postal code</label>
              <input type='text' placeholder='Zip/Postal code' value={zipCode} onChange={ev => setZipCode(ev.target.value)}/>
            </div>
          </div>
          <div>
            <label className='text-gray-700 text-sm font-semibold'>Country</label>
            <input type='text' placeholder='Country' value={country} onChange={ev => setCountry(ev.target.value)}/>
          </div>
          {loginAsUser.admin && (
            <div className='flex gap-2 items-center mb-5'>
              <label htmlFor='admin' className='text-gray-700 text-sm font-semibold'>Admin:</label>
              <input type='checkbox' id='admin' value={'1'} checked={admin} onClick={ev => setAdmin(ev.target.checked)}/>
            </div>
          )}
          <button className='w-full bg-pink-500 text-white p-2 rounded-md hover:opacity-80 duration-300 disabled:cursor-not-allowed'>Save</button>
        </form>
      </div>
  )
}

export default UserForm